==> flink-1.17.2-src.tgz: flink-1.17.2/flink-streaming-java/src/test/java/org/apache/flink/streaming/api/operators/InternalTimeServiceManagerImplTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.streaming.api.operators;

import org.apache.flink.util.TestLogger;

import org.junit.Assert;
import org.junit.Test;

/** Tests for {@link InternalTimeServiceManagerImpl}. */
public class InternalTimeServiceManagerImplTest extends TestLogger {

    /** This test fixes some constants, because changing them can harm backwards compatibility. */
    @Test
    public void fixConstants() {
        String expectedTimerStatePrefix = "_timer_state";
        Assert.assertEquals(
                expectedTimerStatePrefix, InternalTimeServiceManagerImpl.TIMER_STATE_PREFIX);
        Assert.assertEquals(
                expectedTimerStatePrefix + "/processing_",
                InternalTimeServiceManagerImpl.PROCESSING_TIMER_PREFIX);
        Assert.assertEquals(
                expectedTimerStatePrefix + "/event_",
                InternalTimeServiceManagerImpl.EVENT_TIMER_PREFIX);
    }
}

==> flink-1.20.3-src.tgz: flink-1.20.3/flink-streaming-java/src/test/java/org/apache/flink/streaming/api/operators/InternalTimeServiceManagerImplTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.streaming.api.operators;

import org.junit.jupiter.api.Test;

import static org.assertj.core.api.Assertions.assertThat;

/** Tests for {@link InternalTimeServiceManagerImpl}. */
class InternalTimeServiceManagerImplTest {

    /** This test fixes some constants, because changing them can harm backwards compatibility. */
    @Test
    void fixConstants() {
        String expectedTimerStatePrefix = "_timer_state";
        assertThat(InternalTimeServiceManagerImpl.TIMER_STATE_PREFIX)
                .isEqualTo(expectedTimerStatePrefix);
        assertThat(InternalTimeServiceManagerImpl.PROCESSING_TIMER_PREFIX)
                .isEqualTo(expectedTimerStatePrefix + "/processing_");
        assertThat(InternalTimeServiceManagerImpl.EVENT_TIMER_PREFIX)
                .isEqualTo(expectedTimerStatePrefix + "/event_");
    }
}
